Mark the following boards as supported (no board-enable needed)

 - MSI MS-6153 (reported by Uwe Hermann <uwe@hermann-uwe.de>)
   Tested by me on hardware. The board decodes max. 256 KB.

 - MSI MS-6156 (reported by Uwe Hermann <uwe@hermann-uwe.de>)
   Tested by me on hardware. The board decodes max. 256 KB.

Also, fix Dell PowerEdge 1850 name and add some more board URLs.

Corresponding to flashrom svn r749.

Signed-off-by: Uwe Hermann <uwe@hermann-uwe.de>
Acked-by: Uwe Hermann <uwe@hermann-uwe.de>
diff --git a/board_enable.c b/board_enable.c
index 26c0697..bcc5e37 100644
--- a/board_enable.c
+++ b/board_enable.c
@@ -617,10 +617,10 @@
 }
 
 /**
  * Suited for the Dell S1850. All parameters except the last one are documented
  * in the public Intel 82801EB ICH5 / 82801ER ICH5R Datasheet. The last
  * parameter (GPIO number) has to be in the range [16,31] according to said
  * Intel Datasheet and was found by exhaustive search.
  */
 static int ich5_gpio23_raise(const char *name)
 {
@@ -1058,7 +1058,7 @@
 	{0x10B9, 0x1541,      0,      0,  0x10B9, 0x1533,      0,      0, "asus",       "p5a",         "ASUS",        "P5A",                board_asus_p5a},
 	{0x10DE, 0x0030, 0x1043, 0x818a,  0x8086, 0x100E, 0x1043, 0x80EE, NULL,         NULL,          "ASUS",        "P5ND2-SLI Deluxe",   board_asus_p5nd2_sli},
 	{0x1106, 0x3149, 0x1565, 0x3206,  0x1106, 0x3344, 0x1565, 0x1202, NULL,         NULL,          "Biostar",     "P4M80-M4",           it8705_rom_write_enable},
-	{0x8086, 0x3590, 0x1028, 0x016c,  0x1000, 0x0030, 0x1028, 0x016c, NULL,         NULL,          "Dell",        "S1850",              ich5_gpio23_raise},
+	{0x8086, 0x3590, 0x1028, 0x016c,  0x1000, 0x0030, 0x1028, 0x016c, NULL,         NULL,          "Dell",        "PowerEdge 1850",     ich5_gpio23_raise},
 	{0x1106, 0x3038, 0x1019, 0x0996,  0x1106, 0x3177, 0x1019, 0x0996, NULL,         NULL,          "Elitegroup",  "K7VTA3",             it8705f_write_enable_2e},
 	{0x1106, 0x3177, 0x1106, 0x3177,  0x1106, 0x3059, 0x1695, 0x3005, NULL,         NULL,          "EPoX",        "EP-8K5A2",           board_epox_ep_8k5a2},
 	{0x10EC, 0x8139, 0x1695, 0x9001,  0x11C1, 0x5811, 0x1695, 0x9015, NULL,         NULL,          "EPoX",        "EP-8RDA3+",          board_epox_ep_8rda3plus},
@@ -617,10 +617,10 @@
 
 /**
- * Suited for the Dell S1850. All parameters except the last one are documented
- * in the public Intel 82801EB ICH5 / 82801ER ICH5R Datasheet. The last
- * parameter (GPIO number) has to be in the range [16,31] according to said
- * Intel Datasheet and was found by exhaustive search.
+ * Suited for the Dell PowerEdge 1850. All parameters except the last one are
+ * documented in the public Intel 82801EB ICH5 / 82801ER ICH5R datasheet. The
+ * last parameter (GPIO number) has to be in the range [16,31] according to
+ * said Intel datasheet and was found by exhaustive search.
  */
 static int ich5_gpio23_raise(const char *name)